LayoutParser class

Utility class for parsing ASCII strings or grid matrices into structured Seat grids.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaultSeatLabel(int row, int col, int deckIndex) String
Default column letters: A, B, C, D, E, F, G, H...
parseStrings(List<String> stringMap, {int deckIndex = 0, String seatNoBuilder(int row, int col, int deck)?}) List<List<Seat?>>
Parses a list of strings into a 2D matrix of List<List<Seat?>>.