DriverPosition enum
Position of the driver cabin relative to the passenger rows.
Values
- left → const DriverPosition
-
Driver cabin on the front left (standard for left-hand drive countries)
- right → const DriverPosition
-
Driver cabin on the front right (standard for right-hand drive countries)
- center → const DriverPosition
-
Driver cabin centered
- none → const DriverPosition
-
No driver cabin displayed
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DriverPosition> - A constant List of the values in this enum, in order of their declaration.